@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: forms.py 11741 2019-10-08 07:46:25Z Lavender $
+# $Id: forms.py 11745 2019-10-09 02:24:16Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2019-10-08 15:46:25 +0800 (週二, 08 十月 2019) $
-# $Revision: 11741 $
+# $Date: 2019-10-09 10:24:16 +0800 (週三, 09 十月 2019) $
+# $Revision: 11745 $
 
 import os
 import hashlib
@@ -141,7 +141,7 @@ if VERSION >= (2, 0, 0):
         OptionType, TYPE_CHOICES, TEXT, INTEGER, 
         BOOLEAN, FLOAT, DATE, DATETIME, OPTION, RICHTEXT, FILE, IMAGE
     )
-    from Iuppiter.view import FileDragDropWidget
+    from Iuppiter.extension.Widgets import FileDragDropWidget
 
     Option = get_model('catalogue', 'Option')
     ProductAttribute = get_model('catalogue', 'ProductAttribute')
